@@ -5,7 +5,7 @@ use warnings;
 use base qw(POE::Component::SmokeBox::Backend::Base);
 use vars qw($VERSION);
 
-$VERSION = '0.44';
+$VERSION = '0.46';
 
 sub _data {
   my $self = shift;
@@ -13,7 +13,7 @@ sub _data {
   {
 	check => [ '-e', 1 ],
 	index => [ '-e', 1 ],
-	smoke => [ '-e', '$|=1; my $module = shift; print $module, qq{\n}; sleep 5; exit 0;' ],
+	smoke => [ '-e', '$|=1; if ( $ENV{PERL5LIB} ) { print $ENV{PERL5LIB}, qq{\n}; } else { my $module = shift; print $module, qq{\n}; } sleep 5; exit 0;' ],
   };
   return;
 }
